/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({})
@Inherited
/**
 * Represents Navigation rules
 * Use the PageType for resolve the render pages.
 * Use the currentView for prepare methods, like prepareInsert
 * Use the previousView for executed methods like insert.
 * 
 * @author SERPRO/CETEC
 */
public @interface NavigationRule {

	/**
	 * Represents the current page outcome.
	 * 
	 * @return
	 */
	String currentView() default "";

	/**
	 * Represents the previous page outcome.
	 * 
	 * @return
	 */
	String previousView() default "";

	/**
	 * Represents the page title.
	 * 
	 * @return
	 */
	String title();

	/**
	 * Represents the type of the page to display.
	 * @return
	 */
	PageType type();
	
}