/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.layer;

import java.io.Serializable;
import java.util.List;

import br.gov.component.demoiselle.crud.exception.DemoiselleCrudException;
import br.gov.framework.demoiselle.core.bean.IPojo;
import br.gov.framework.demoiselle.core.layer.IBusinessController;

/**
 * Provide a CRUD behaviour for Business classes: Create, Retrieve, Update, Delete.
 * Additionaly, provides listing and filtered listing operations.
 *
 * @param <P extends IPojo> br.gov.framework.demoiselle.core.bean.IPojo
 *
 * @author SERPRO/CETEC
 */
public interface ICrudBC<P extends IPojo> extends IBusinessController {

	/**
	 * List all persisted Pojos according filter matching
	 *
	 * @param filter P extends IPojo
	 *            Filter Object
	 * @return Pojo List
	 */
	public List<P> find(P filter) throws DemoiselleCrudException;

	/**
	 * Returns all Pojos
	 *
	 * @return Pojo List
	 */
	public List<P> findAll() throws DemoiselleCrudException;

	/**
	 * Removes a persisted Pojo instance
	 *
	 * @param id
	 *            Pojo ID
	 */
	void delete(P pojo) throws DemoiselleCrudException;

	/**
	 * Persists a new Pojo instance
	 *
	 * @param pojo
	 *            Pojo instance
	 */
	void insert(P pojo) throws DemoiselleCrudException;

	/**
	 * Loads a persisted Pojo instance
	 *
	 * @param id
	 *            Pojo ID
	 * @return Pojo instance
	 */
	P load(Serializable id) throws DemoiselleCrudException;

	/**
	 * Updates a persisted Pojo instance
	 *
	 * @param pojo
	 *            Pojo instance
	 */
	void update(P pojo) throws DemoiselleCrudException;

}
