/*
 * Demoiselle Framework
 * Copyright (c) 2009 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.layer;

import br.gov.framework.demoiselle.core.bean.IPojo;

/**
 * Represents a Page that allows Pojo editing (delete, insert and update)
 * 
 * @param <P> Pojo
 * @param <I> Pojo ID
 * 
 * @author SERPRO/CETEC
 */
public interface ICrudMB<P extends IPojo> extends IShowMB<P> {

	/**
	 * Removes current Pojo from the collection.
	 * 
	 * @return String containing the outcome Page after removal
	 */
	public String delete();

	/**
	 * Inserts a new Pojo into the collection.
	 * 
	 * @return String containing the outcome Page after insert
	 */
	public String insert();

	/**
	 * Returns true if current Pojo is in update mode (user can view, update or delete).
	 * 
	 * @return 
	 */
	public boolean isUpdateMode();

	/**
	 * Updates current Pojo.
	 * 
	 * @return String containing the outcome Page after upodate
	 */
	public String update();
	

	/**
	 * Returns true if current Pojo is Read Ony (user cannot view, update or delete).
	 * 
	 * @return String containing the outcome Page after insert
	 */
	public boolean isShowOnly();
	
}
