/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.layer.integration;

import org.apache.log4j.Logger;

import br.gov.component.demoiselle.crud.layer.ICrudBC;
import br.gov.component.demoiselle.crud.supercrud.ImplicitSuperCrudBC;
import br.gov.framework.demoiselle.core.bean.IPojo;
import br.gov.framework.demoiselle.core.layer.integration.IFactory;
import br.gov.framework.demoiselle.core.layer.integration.InjectionContext;
import br.gov.framework.demoiselle.util.Constant;
import br.gov.framework.demoiselle.util.config.ConfigurationLoader;
import br.gov.framework.demoiselle.web.layer.integration.WebLayerIntegrationException;

/**
 * Especial factory to inject an ICrudBC.
 * It can be an user implementation or an internal implementation.
 *
 * @version %I%, %G%
 * @see br.gov.component.demoiselle.crud.layer.ICrudBC
 * @see br.gov.component.demoiselle.crud.supercrud.ImplicitSuperCrudBC
 */
public class CrudBusinessControllerFactory extends CrudFactory implements IFactory<ICrudBC<?>> {

	private static Logger log = Logger.getLogger(CrudBusinessControllerFactory.class);

	/**
	 * This method find the correct implemantarion of ICrudBC
	 * @see br.gov.component.demoiselle.crud.layer.ICrudBC;
	 */
	public ICrudBC<?> create(InjectionContext ctx) {
		return create(getPojoClass(ctx.getClassType()));
	}

	/**
	 * First search for user implementation using the pattern defined in the configurator file.
	 * If isnt an implemantation, then instanciate an internal class @see ImplicitSuperCrudBC;
	 *
	 * @param pojo
	 * @return
	 */
	public ICrudBC<?> create(Class<IPojo> pojo) {
		ICrudBC<?> bc = null;
		CrudFactoryConfig config = ConfigurationLoader.load(CrudFactoryConfig.class);
		if(config.hasBusiness()){
			log.debug("Looking for user implementation. Based on "+ Constant.FRAMEWORK_CONFIGURATOR_FILE);
            String className = conventionForClassName(pojo.getName(),config.getRegexBusiness(), config.getReplaceBusiness());
			try {
	            bc = (ICrudBC<?>) createWithLazyCreateProxy(Class.forName(className));
			} catch (ClassNotFoundException e) {
				log.debug("No user implementation found");
			} catch (ClassCastException e) {
				throw new WebLayerIntegrationException("It should be an instance of ICrudBC");
			}
		}else{
			log.debug("No user implementation configured in "+ Constant.FRAMEWORK_CONFIGURATOR_FILE);
		}

		if(bc == null){
			log.debug("Loading the ImplicitSuperCrudBC");
			bc = new ImplicitSuperCrudBC(pojo);
		}

		return bc;
	}


}
