/*
 * Demoiselle Framework
 * Copyright (c) 2009 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.message;

import java.util.Locale;
import java.util.ResourceBundle;

import br.gov.framework.demoiselle.core.message.Severity;

/**
 * All internal messages for crud operations.
 * These messages always use resource bundle.
 *
 * @author SERPRO/CETEC
 */
public enum CrudMessages implements ICrudMessage {

	CRUD_INSERT_OK("crud.insert.ok", Severity.INFO),
	CRUD_UPDATE_OK("crud.update.ok", Severity.INFO),
	CRUD_DELETE_OK("crud.delete.ok", Severity.INFO),
	CRUD_FIND_OK("crud.find.ok", Severity.INFO),

	CRUD_INSERT_NOK("crud.insert.nok", Severity.ERROR,"app.{0}.insert.nok"),
	CRUD_UPDATE_NOK("crud.update.nok", Severity.ERROR),
	CRUD_DELETE_NOK("crud.delete.nok", Severity.ERROR),
	CRUD_FIND_NOK("crud.find.nok", Severity.ERROR),

	CRUD_LOAD_NOK("crud.load.nok", Severity.ERROR),
	CRUD_FIND_BY_FILTER_NOK("crud.find.by.filter.nok", Severity.ERROR),
	CRUD_FIND_ALL_NOK("crud.find.all", Severity.ERROR)
	;

	private String key = null;
	private String customPattern = null;
	private Severity severity;
	private String resourceName = "messages";

	private CrudMessages(String key, Severity severity) {
		this.key = key;
		this.severity = severity;
		this.customPattern = key.replaceAll("crud.", "app.{0}.");
	}

	private CrudMessages(String key, Severity severity, String customPattern) {
		this(key,severity);
		this.customPattern = customPattern;
	}

	public String getKey() {
		return this.key;
	}

	public String getLabel() {
		ResourceBundle bundle = ResourceBundle.getBundle(getResourceName());
		if(bundle.containsKey(getKey())){
			return bundle.getString(getKey());
		}else{
			return "???"+getKey()+"???";
		}
	}

	public Locale getLocale() {
		return new Locale("pt", "BR");
	}

	public Severity getSeverity() {
		return severity;
	}

	public String getResourceName() {
		return resourceName;
	}

	public String getCustomPattern() {
		return customPattern;
	}

}