/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.message;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.faces.context.FacesContext;

import org.apache.log4j.Logger;

import br.gov.framework.demoiselle.core.message.IMessage;
import br.gov.framework.demoiselle.core.message.Severity;

/**
 * This class decorate a message, considering an optional custom
 * message for all crud operations per application.
 *
 * It justs decorates the getLabel method to use the bundle.
 *
 * @author SERPRO/CETEC
 */
public class MessageDecorator implements IMessage{

	private static Logger log = Logger.getLogger(MessageDecorator.class);

	private ICrudMessage msg;
	private String name;
	private Object[] args;

	public MessageDecorator(ICrudMessage msg, String name, Object...args) {
		this.msg = msg;
		this.name = name;
		this.args = args;
	}

	public String getKey() {
		return this.msg.getKey();
	}

	/**
	 * Use the message pattern to get the bundle message;
	 * If it doesn't exists, then use the key;
	 */
	public String getLabel() {
		
		String label = msg.getLabel();
		String customKey = MessageFormat.format(msg.getCustomPattern(), name);
		
		Locale usrLocale = getUserLocale(msg.getLocale());
		ResourceBundle bundle = ResourceBundle.getBundle(msg.getResourceName(),usrLocale);
		
		if(bundle.containsKey(customKey)){
			label = bundle.getString(customKey);
		}else {
			label = bundle.getString(msg.getKey());
		}

		if(args!=null && args.length>0){
			label = MessageFormat.format(label, args);
		}

		return label;
	}

	private Locale getUserLocale(Locale usrLocale) {
		try{
			usrLocale = FacesContext.getCurrentInstance().getViewRoot().getLocale();
		}catch (Exception e) {
			log.error("Cant load user locale from FacesContext", e);
		}
		return usrLocale;
	}

	public Locale getLocale() {
		return this.msg.getLocale();
	}

	public String getResourceName() {
		return this.msg.getResourceName();
	}

	public Severity getSeverity() {
		return this.msg.getSeverity();
	}

}
