/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.supercrud;

import br.gov.component.demoiselle.crud.layer.ICrudBC;
import br.gov.component.demoiselle.crud.layer.ICrudDAO;
import br.gov.component.demoiselle.crud.layer.integration.CrudDAOFactory;
import br.gov.framework.demoiselle.core.bean.IPojo;
import br.gov.framework.demoiselle.core.layer.IBusinessController;
import br.gov.framework.demoiselle.core.layer.integration.Injection;

/**
 * Default implementation for the {@link ICrudBC} interface.
 * Instanciate the DAO using the {@link CrudDAOFactory}
 *
 */
public class ImplicitSuperCrudBC  extends SuperCrudBC<IPojo> implements ICrudBC<IPojo>, IBusinessController{

	private static final long serialVersionUID = -4485403656815487789L;

	/**
	 * This field isnt visible for aspect, because
	 * no user class use it directly;
	 */
	@Injection(factory=CrudDAOFactory.class)
	private ICrudDAO<IPojo> dao;

	private Class<? extends IPojo> pojoClass;

	public ImplicitSuperCrudBC(Class<? extends IPojo> pojo) {
		this.pojoClass = (Class<IPojo>) pojo;
	}

	@SuppressWarnings("unchecked")
	@Override
	protected ICrudDAO<IPojo> getDAO() {
		if(dao==null){
			dao = (ICrudDAO<IPojo>) new CrudDAOFactory().createDAO(pojoClass);
		}
		return dao;
	}
}
