/*
 * Demoiselle Framework
 * Copyright (c) 2009 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.supercrud;

import org.apache.log4j.Logger;

import br.gov.component.demoiselle.crud.exception.DemoiselleCrudException;
import br.gov.framework.demoiselle.core.bean.IPojo;

/**
 * @author SERPRO/CETEC
 */
public class SuperAjaxCrudMB<P extends IPojo> extends SuperCrudMB<P>{

	private static final long serialVersionUID = 9199330476487866658L;

	private static Logger log = Logger.getLogger(SuperAjaxCrudMB.class);

	/**
	 * Represents States of operations for a crud
	 */
	public enum State {FIND, SHOW, INSERT, UPDATE, DELETE};

	/**
	 * Current state of crud operations.
	 * Starts in FIND mode;
	 */
	private State currentState = State.FIND;

	public String prepareInsert() {
		log.debug("Preparing form for insert action");
		setCurrentState(State.INSERT);
		clear();
		return null;
	}

	public String prepareUpdate() {
		log.debug("Preparing form for update action");
		setCurrentState(State.UPDATE);
		initPojo();
		return null;
	}

	public String prepareDelete() {
		log.debug("Preparing form for delete action");
		setCurrentState(State.DELETE);
		initPojo();
		return null;
	}

	protected String handleDelete() throws DemoiselleCrudException {
		log.debug("Executing delete action");
		getBC().delete(getPojo());
		list();
		return null;
	}

	protected String handleInsert() throws DemoiselleCrudException {
		log.debug("Executing insert action");
		getBC().insert(getPojo());
		list();
		return null;
	}

	protected String handleUpdate() throws DemoiselleCrudException {
		log.debug("Executing update action");
		getBC().update(getPojo());
		list();
		return null;
	}

	/**
	 * Set the current state to FIND,
	 * Clear the selection and datamodel
	 * returns the super behaviour;
	 */
	@Override
	public String list() {
		setCurrentState(State.FIND);
		return super.list();
	}

	public State getCurrentState() {
		return this.currentState;
	}

	public void setCurrentState(State state) {
		log.debug("Seting state to: "+state.toString());
		this.currentState = state;
	}

	public boolean isFindState() {
		return (State.FIND.equals(this.getCurrentState()));
	}

	public boolean isShowState() {
		return (State.SHOW.equals(this.getCurrentState()));
	}

	public boolean isInsertState() {
		return (State.INSERT.equals(this.getCurrentState()));
	}

	public boolean isUpdateState() {
		return (State.UPDATE.equals(this.getCurrentState()));
	}

	public boolean isDeleteState() {
		return (State.DELETE.equals(this.getCurrentState()));
	}

	/**
	 * Always returns the current view except when from a view state.
	 * Set the currentState FIND;
	 * In this case returns the annotated previousView
	 */
	@Override
	public String getPreviousView() {
		if(currentState.equals(State.INSERT)
			||currentState.equals(State.UPDATE)
			||currentState.equals(State.DELETE)
			||currentState.equals(State.SHOW)){
			setCurrentState(State.FIND);
			return null;
		}
		return super.getPreviousView();
	}

}
