/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.supercrud;

import java.io.Serializable;
import java.util.List;

import br.gov.component.demoiselle.crud.exception.DemoiselleCrudException;
import br.gov.component.demoiselle.crud.layer.ICrudBC;
import br.gov.component.demoiselle.crud.message.CrudMessages;
import br.gov.component.demoiselle.crud.template.AbstractBC;
import br.gov.framework.demoiselle.core.bean.IPojo;

/**
 * Default implementation for the {@link ICrudBC} interface.
 *
 * @param <P>
 *            Pojo
 * @param <I>
 *            Pojo ID
 * @param <D>
 *            DAO
 * @param <F>
 *            Filter
 */
public class SuperCrudBC<P extends IPojo> extends AbstractBC<P>	implements ICrudBC<P> {

	/**
	 * Serialization Version UID
	 */
	private static final long serialVersionUID = 1L;

	/*
	 * (non-Javadoc)
	 * @see br.gov.component.demoiselle.crud.layer.ICrudBC#delete(java.io.Serializable)
	 */
	public void delete(final P pojo) {
		try {
			getDAO().remove(pojo);
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_DELETE_NOK,t);
		}
	}

	public List<P> find(final P filter) {
		try {
			List<P> list = getDAO().find(filter);
			return list;
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_FIND_BY_FILTER_NOK,t);
		}
	}

	/*
	 * (non-Javadoc)
	 * @see br.gov.component.demoiselle.crud.layer.IListBC#findAll()
	 */
	public List<P> findAll() {
		try {
			List<P> list = getDAO().findAll();
			return list;
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_FIND_ALL_NOK,t);
		}
	}

	/*
	 * (non-Javadoc)
	 * @see br.gov.component.demoiselle.crud.layer.ICrudBC#insert(br.gov.framework.demoiselle.core.bean.IPojo)
	 */
	public void insert(final P pojo) {
		try {
			getDAO().insert(pojo);
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_INSERT_NOK,t);
		}
	}

	/*
	 * (non-Javadoc)
	 * @see br.gov.component.demoiselle.crud.layer.ICrudBC#load(java.io.Serializable)
	 */
	public P load(final Serializable id) {
		try {
			P pojo = getDAO().findById(id);
			return pojo;
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_LOAD_NOK,t);
		}
	}

	/*
	 * (non-Javadoc)
	 * @see br.gov.component.demoiselle.crud.layer.ICrudBC#update(br.gov.framework.demoiselle.core.bean.IPojo)
	 */
	public void update(final P pojo) {
		try {
			getDAO().update(pojo);
		} catch (Throwable t) {
			throw new DemoiselleCrudException(CrudMessages.CRUD_UPDATE_NOK,t);
		}
	}

}
