/*
 * Demoiselle Framework
 * Copyright (c) 2009 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.template;

import java.io.Serializable;

import br.gov.component.demoiselle.crud.layer.ICrudDAO;
import br.gov.component.demoiselle.crud.layer.integration.CrudDAOFactory;
import br.gov.component.demoiselle.crud.util.GenericsReader;
import br.gov.framework.demoiselle.core.bean.IPojo;
import br.gov.framework.demoiselle.core.layer.IBusinessController;
import br.gov.framework.demoiselle.core.layer.integration.Injection;

/**
 * Represents Business classes which accesses DAO objects to manage Pojo
 *
 *
 * @param <P>
 *            Pojo
 * @param <I>
 *            Pojo ID
 * @param <D>
 *            DAO
 */
public abstract class AbstractBC<P extends IPojo> implements IBusinessController, Serializable {

	/**
	 * Serialization Version UID
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * The DAO instance
	 */
	@Injection(factory=CrudDAOFactory.class)
	private ICrudDAO<P> dao;

	/**
	 * @see #dao
	 * @return The DAO
	 */
	protected ICrudDAO<P> getDAO() {
		if(dao==null){
			dao = (ICrudDAO<P>)new CrudDAOFactory().createDAO((Class<IPojo>) getPojoClass());
		}
		return this.dao;
	}

	protected Class<P> getPojoClass(){
		return GenericsReader.getTypeArgument(this.getClass(), 0);
	}

}
