/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.layer.integration;

import static org.junit.Assert.assertEquals;

import java.lang.annotation.Annotation;
import java.lang.reflect.Proxy;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import testApp.business.implementation.AllLayersBC;
import testApp.view.managedBean.NoLayersMB;
import testApp.view.managedBean.AllLayersMB;
import br.gov.component.demoiselle.crud.layer.ICrudBC;
import br.gov.component.demoiselle.crud.supercrud.ImplicitSuperCrudBC;
import br.gov.framework.demoiselle.core.layer.integration.IFactory;
import br.gov.framework.demoiselle.core.layer.integration.Injection;
import br.gov.framework.demoiselle.core.layer.integration.InjectionContext;
import br.gov.framework.demoiselle.util.layer.integration.LazyCreateProxy;

public class CrudBusinessControllerFactoryTest {

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testCreateUsingUserBC() {
		InjectionContext ctx = new InjectionContext(annotation,ICrudBC.class, AllLayersMB.class);
		CrudBusinessControllerFactory factory = new CrudBusinessControllerFactory();
		ICrudBC<?> bc = factory.create(ctx);

		Assert.assertNotNull("Cound not find the user implementation",bc);
		if (Proxy.isProxyClass(bc.getClass())) {
			assertEquals(AllLayersBC.class, ((LazyCreateProxy) Proxy.getInvocationHandler(bc)).getInternalClass());
		} else {
			assertEquals(AllLayersBC.class, bc.getClass());
		}

	}

	@Test
	public void testCreateUsingImplicitBC() {
		InjectionContext ctx = new InjectionContext(annotation,ICrudBC.class, NoLayersMB.class);
		CrudBusinessControllerFactory factory = new CrudBusinessControllerFactory();
		ICrudBC<?> bc = factory.create(ctx);

		Assert.assertNotNull("Cound not find the generic implementation",bc);
		if (Proxy.isProxyClass(bc.getClass())) {
			assertEquals(ImplicitSuperCrudBC.class, ((LazyCreateProxy) Proxy.getInvocationHandler(bc)).getInternalClass());
		} else {
			assertEquals(ImplicitSuperCrudBC.class, bc.getClass());
		}

	}


	Injection annotation = new Injection() {
		public Class<? extends Annotation> annotationType() {
			return Injection.class;
		}
		public String[] parameters() {
			return new String[]{""};
		}
		public String name() {
			return null;
		}
		@SuppressWarnings("unchecked")
		public Class<? extends IFactory> factory() {
			return CrudBusinessControllerFactory.class;
		}
	};

}
