package br.gov.component.demoiselle.crud.supercrud;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import br.gov.component.demoiselle.crud.annotation.Input;
import br.gov.component.demoiselle.crud.annotation.input.Calendar;
import br.gov.component.demoiselle.crud.annotation.input.Cpf;
import br.gov.component.demoiselle.crud.annotation.input.Mask;
import br.gov.component.demoiselle.crud.annotation.input.Number;
import br.gov.component.demoiselle.crud.annotation.input.Text;
import br.gov.framework.demoiselle.core.bean.IPojo;

public class ElementTest {

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testGetInput() {
		SuperAjaxCrudMB<MyBean> mb = new SuperCrudMB();
		List<Element> elements = mb.getColumns();

		int i = 0;
		for (Element e : elements) {
			if (i == 0)
				Assert.assertEquals("text", e.getInput());
			if (i == 1)
				Assert.assertEquals("mask", e.getInput());
			if (i == 2)
				Assert.assertEquals("calendar", e.getInput());
			if (i == 3)
				Assert.assertEquals("number", e.getInput());
			if (i == 4)
				Assert.assertEquals("cpf", e.getInput());
			if (i == 5)
				Assert.assertEquals("text", e.getInput());
			if (i == 6)
				Assert.assertEquals("newType", e.getInput());
			i++;
		}
	}

	@Test
	public void testGetInputTemplate() {
		SuperAjaxCrudMB<MyBean> mb = new SuperCrudMB();
		List<Element> elements = mb.getColumns();

		int i = 0;
		for (Element e : elements) {
			if (i == 6)
				Assert.assertEquals("newInputTemplate.xhtml", e.getInputTemplate());
			else
				Assert.assertEquals("",e.getInputTemplate());
			i++;
		}
	}

	@Test
	public void testGetInputAttribute() {
		SuperAjaxCrudMB<MyBean> mb = new SuperCrudMB();
		List<Element> elements = mb.getColumns();

		int i = 0;
		for (Element e : elements) {
			if (i == 1)
				Assert.assertEquals("99.999", e.getInputAttribute("value"));
			else if (i == 3) {
				Assert.assertEquals("3", e.getInputAttribute("precision"));
				Assert.assertEquals("$", e.getInputAttribute("prefix"));
				Assert.assertEquals(",", e.getInputAttribute("centsSeparator"));
				Assert.assertEquals(".", e
						.getInputAttribute("thousandsSeparator"));
			} else {
				Assert.assertNull(e.getInputAttribute("value"));
			}
			i++;
		}
	}

	@Test
	public void testGetInputAttributes() {
		SuperAjaxCrudMB<MyBean> mb = new SuperCrudMB();
		List<Element> elements = mb.getColumns();

		int i = 0;
		for (Element e : elements) {
			if (i == 1)
				Assert.assertEquals("99.999", e.getInputAttribute("value"));
			else if (i == 3)
				Assert.assertEquals(4, e.getInputAttributes().size());
			else
				Assert.assertEquals(0, e.getInputAttributes().size());
			i++;
		}
	}

	@Input("newInputTemplate.xhtml")
	@Documented
	@Retention(RetentionPolicy.RUNTIME)
	@Target(value = { ElementType.FIELD })
	public @interface NewType {

	}

	@Entity
	private class MyBean implements IPojo {
		private static final long serialVersionUID = 1L;

		@Text
		@Column
		private String field1;

		@Mask("99.999")
		@Column
		private String field2;

		@Column
		@Calendar
		private String field3;

		@Column
		@Number(prefix = "$", precision = 3)
		private String field4;

		@Column
		@Cpf
		private String field5;

		@Column
		private String field6;

		@Column
		@NewType
		private String field7;
	}

	@SuppressWarnings("serial")
	private class SuperCrudMB extends SuperAjaxCrudMB<MyBean> {
	}
}
