/*
 * Demoiselle Framework
 * Copyright (c) 2010 Serpro and other contributors as indicated
 * by the @author tag. See the copyright.txt in the distribution for a
 * full listing of contributors.
 *
 * Demoiselle Framework is an open source Java EE library designed to accelerate
 * the development of transactional database Web applications.
 *
 * Demoiselle Framework is released under the terms of the LGPL license 3
 * http://www.gnu.org/licenses/lgpl.html  LGPL License 3
 *
 * This file is part of Demoiselle Framework.
 *
 * Demoiselle Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License 3 as published by
 * the Free Software Foundation.
 *
 * Demoiselle Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Demoiselle Framework.  If not, see <http://www.gnu.org/licenses/>.
 */
package br.gov.component.demoiselle.crud.supercrud;

import static org.junit.Assert.fail;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;

import junit.framework.Assert;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import testApp.bean.AllLayers;
import br.gov.component.demoiselle.crud.annotation.Input;
import br.gov.component.demoiselle.crud.annotation.Page;
import br.gov.component.demoiselle.crud.annotation.input.Cpf;
import br.gov.component.demoiselle.crud.annotation.input.Calendar;
import br.gov.component.demoiselle.crud.annotation.input.Mask;
import br.gov.component.demoiselle.crud.annotation.input.Number;
import br.gov.component.demoiselle.crud.annotation.input.Text;
import br.gov.component.demoiselle.crud.layer.ICrudBC;
import br.gov.component.demoiselle.crud.supercrud.SuperAjaxCrudMB.State;
import br.gov.framework.demoiselle.core.bean.IPojo;

public class SuperAjaxCrudMBTest {

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@SuppressWarnings("unchecked")
	@Test
	public void testGetPreviousViewWithPageAnnotation() {
		SuperAjaxCrudMB mb = new SuperAjaxCrud1();

		mb.setCurrentState(State.INSERT);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.UPDATE);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.DELETE);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.SHOW);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.FIND);
		Assert.assertEquals("previousView", mb.getPreviousView());

	}

	@SuppressWarnings("unchecked")
	@Test
	public void testGetPreviousViewWithoutPageAnnotation() {
		SuperAjaxCrudMB mb = new SuperAjaxCrud2();

		mb.setCurrentState(State.INSERT);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.UPDATE);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.DELETE);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.SHOW);
		Assert.assertEquals(null, mb.getPreviousView());
		Assert.assertEquals(State.FIND, mb.getCurrentState());

		mb.setCurrentState(State.FIND);
		Assert.assertEquals(null, mb.getPreviousView());

	}

	@Test
	public void testIsFindState() {
		SuperAjaxCrudMB<?> mb = new SuperAjaxCrud1();
		mb.setCurrentState(State.FIND);
		Assert.assertTrue(mb.isFindState());
	}

	@Test
	public void testIsShowState() {
		SuperAjaxCrudMB<?> mb = new SuperAjaxCrud1();
		mb.setCurrentState(State.SHOW);
		Assert.assertTrue(mb.isShowState());
	}

	@Test
	public void testIsInsertState() {
		SuperAjaxCrudMB<?> mb = new SuperAjaxCrud1();
		mb.setCurrentState(State.INSERT);
		Assert.assertTrue(mb.isInsertState());
	}

	@Test
	public void testIsUpdateState() {
		SuperAjaxCrudMB<?> mb = new SuperAjaxCrud1();
		mb.setCurrentState(State.UPDATE);
		Assert.assertTrue(mb.isUpdateState());
	}

	@Test
	public void testIsDeleteState() {
		SuperAjaxCrudMB<?> mb = new SuperAjaxCrud1();
		mb.setCurrentState(State.DELETE);
		Assert.assertTrue(mb.isDeleteState());
	}

	@SuppressWarnings("serial")
	@Page(title="title", currentView="currentVIew", previousView="previousView")
	private class SuperAjaxCrud1 extends SuperAjaxCrudMB<AllLayers>{

	}

	@SuppressWarnings("serial")
	private class SuperAjaxCrud2 extends SuperAjaxCrudMB<AllLayers>{

	}
}
