package teste.simplify.bean;

import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

import org.eclipse.persistence.annotations.TimeOfDay;
import org.hibernate.validator.constraints.Email;
import org.hibernate.validator.constraints.NotEmpty;

import br.gov.component.demoiselle.crud.annotation.Label;
import br.gov.component.demoiselle.crud.annotation.input.Calendar;
import br.gov.component.demoiselle.crud.annotation.input.Cpf;
import br.gov.component.demoiselle.crud.annotation.input.Currency;
import br.gov.component.demoiselle.crud.annotation.input.Tel;
import br.gov.framework.demoiselle.core.bean.IPojo;

@Entity
@SuppressWarnings("serial")
public class Pessoa implements IPojo {

    @Id
    @GeneratedValue
    @Column(nullable = false)
    private Long id;

    @Size(max = 50)
    @NotNull
    @NotEmpty()
    @Label("Nome")
    private String nome;

    @Label("Telefone")
    @Tel
    private String telefone;

    @NotNull
    @NotEmpty()
    @Label("CPF/CNPJ")
    @Cpf
    private String cpfCnpj;

    @NotNull
    @Email()
    @NotEmpty()
    @Label("E-mail")
    private String eMail;

    @NotNull
    @Label("Data de Nascimento")
    @Calendar
    @Temporal(TemporalType.DATE)
    private Date dataNascimento;

    @NotNull
    @Label("Salário")
    @Currency
    private Double salario;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getNome() {
        return nome;
    }

    public void setNome(String nome) {
        this.nome = nome;
    }

    public String getTelefone() {
        return telefone;
    }

    public void setTelefone(String telefone) {
        this.telefone = telefone;
    }

    public String getCpfCnpj() {
        return cpfCnpj;
    }

    public void setCpfCnpj(String cpfCnpj) {
        this.cpfCnpj = cpfCnpj;
    }

    public String geteMail() {
        return eMail;
    }

    public void seteMail(String eMail) {
        this.eMail = eMail;
    }

    public Date getDataNascimento() {
        return dataNascimento;
    }

    public void setDataNascimento(Date dataNascimento) {
        this.dataNascimento = dataNascimento;
    }

    public Double getSalario() {
        return salario;
    }

    public void setSalario(Double salario) {
        this.salario = salario;
    }
}
